CREATE TABLE `communeEPCI` (
  `id` int PRIMARY KEY AUTO_INCREMENT,
  `name` VARCHAR(512),
  `region` VARCHAR(128),
  `publicPageSlug` VARCHAR(256),
  `hasPublicPage` TINYINT(1),
  `version` INT,
  `createdAt` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` DATETIME DEFAULT  CURRENT_TIMESTAMP,
  `archivedAt` DATETIME,
    INDEX `name_region` (name, region)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `user` (
  `id` INT PRIMARY KEY AUTO_INCREMENT,
  `communeEPCI_id` INT,
  `fullName` VARCHAR(128),
  `email` VARCHAR(128),
  `password` VARCHAR(256),
  `roles` JSON,
  `emailVerified` TINYINT,
  `version` INT,
  `createdAt` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` DATETIME DEFAULT  CURRENT_TIMESTAMP,
  `archivedAt` DATETIME
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `invitation` (
  `userId` INT COMMENT 'the user invited > is already created',
  `validator` VARCHAR(32),
  `selector` VARCHAR(8) COMMENT 'see https://paragonie.com/blog/2017/02/split-tokens-token-based-authentication-protocols-without-side-channels',
  `expiresAt` DATETIME,
  PRIMARY KEY (`selector`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `reset_password_request` (
  `id` int PRIMARY KEY AUTO_INCREMENT,
  `user_id` int,
  `selector` varchar(20),
  `hashed_token` varchar(100),
  `requested_at` datetime,
  `expires_at` datetime
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `ficheAction` (
  `reference` VARCHAR(256) UNIQUE PRIMARY KEY COMMENT 'see reponse.inputName',
  `viewOrder` INT,
  `title` VARCHAR(512),
  `slug` varchar(256) DEFAULT NULL,
  `theme` VARCHAR(64),
  `content` LONGTEXT,
  `preview` MEDIUMTEXT,
  `version` INT,
  `createdAt` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` DATETIME DEFAULT  CURRENT_TIMESTAMP,
  `archivedAt` DATETIME
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `diagnosticICL` (
  `uuid` VARCHAR(36) PRIMARY KEY,
  `communeEPCI_id` INT,
  `ownerId` INT COMMENT 'user who started the questionnaire',
  `duplicatedFrom` VARCHAR(36) COMMENT 'diagnosticICL.uuid',
  `name` VARCHAR(256),
  `version` INT,
  `createdAt` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` DATETIME DEFAULT  CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `reponseICL` (
  `diagUuid` VARCHAR(36),
  `inputName` VARCHAR(128) COMMENT '<diagnostic_step>-<step_chapter>-<question_name>',
  `step` VARCHAR(32),
  `value` TEXT,
  `ficheActionRef` VARCHAR(256) COMMENT 'ficheAction.Reference',
  `version` INT,
  `createdAt` DATETIME DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` DATETIME DEFAULT  CURRENT_TIMESTAMP,
  PRIMARY KEY (`diagUuid`, `inputName`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

CREATE TABLE `inviteConsultantToken` (
  `selector` varchar(8) UNIQUE PRIMARY KEY,
  `hashedVerifier` varchar(100),
  `userId` int ,
  `diagUuid` varchar(36),
  `questionInputName` varchar(128),
  `expiresAt` datetime
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;


CREATE TABLE `reponseLogisticien` (
  `id` INT PRIMARY KEY AUTO_INCREMENT,
  `communeEPCI_id` INT,
  `nomCollectivite` VARCHAR(255),
  `entrepriseRepondante` VARCHAR(255),
  `evalReglementation` INT,
  `reglementationCommentaire` VARCHAR(1024),
  `evalFoncier` INT,
  `foncierCommentaire` VARCHAR(1024),
  `evalAmenagementNombreSecu` INT,
  `evalAmenagementExistenceLieu` INT,
  `evalAmenagementAireStatio` INT,
  `amenagementCommentaire` VARCHAR(1024),
  `evalPolitique` INT,
  `politiqueCommentaire` VARCHAR(1024),
  `evalEmploi` INT,
  `emploiCommentaire` VARCHAR(1024),
  `evalInvestissement` INT,
  `investissementCommentaire` VARCHAR(1024),
  `evalCommunication` INT,
  `communicationCommentaire` VARCHAR(1024),
  `pioriteActionFoncier` INT,
  `pioriteActionAménagement` INT,
  `pioriteActionRéglementation` INT,
  `pioriteActionEmploi` INT,
  `pioriteActionInvestissement` INT,
  `pioriteActionCommuication` INT,
  `createdAt` datetime default current_timestamp
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;


