/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

import 'sortable'


const rankingContainer = document.querySelector('[data-ranking-container]'),
  clickHandler = {

    handleEvent: function (event) {
      const handler = event.target.dataset[event.type]

      if (!handler || !this[handler]) return

      this[handler](event)
    },
    // https://stackoverflow.com/a/46725046
    up: function (event) {
      const rankingItem = event.target.closest('.ranking-item');

      if (rankingItem.previousElementSibling) {
        rankingItem.parentNode.insertBefore(rankingItem, rankingItem.previousElementSibling);
      }
    },
    down: function (event) {
      const rankingItem = event.target.closest('.ranking-item');

      if (rankingItem.nextElementSibling) {
        rankingItem.parentNode.insertBefore(rankingItem.nextElementSibling, rankingItem);
      }
    },
  },
  sortableInstance = new Sortable(rankingContainer, {
    draggable: ".ranking-item",
    ghostClass: "sortable-ghost",  // Class name for the drop placeholder
    chosenClass: "sortable-chosen",  // Class name for the chosen item
    dragClass: "sortable-drag",  // Class name for the dragging item
  })
;

rankingContainer.addEventListener('click', clickHandler)


