/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

import 'sortable'

htmx.onLoad(function (content) {
  var sortable = document.querySelector(".sortable");
  var sortableInstance = new Sortable(sortable, {
    animation: 150,
    draggable: ".ranking-item",
    ghostClass: "sortable-ghost",  // Class name for the drop placeholder
    chosenClass: "sortable-chosen",  // Class name for the chosen item
    dragClass: "sortable-drag",  // Class name for the dragging item

    // Make the `.htmx-indicator` unsortable
    filter: ".htmx-indicator",
    onMove: function (evt) {
      return evt.related.className.indexOf('htmx-indicator') === -1;
    },

    // Disable sorting on the `end` event
    onEnd: function (evt) {
      this.option("disabled", true);
    }
  });

  // Re-enable sorting on the `htmx:afterSwap` event
  sortable.addEventListener("htmx:afterSwap", function () {
    sortableInstance.option("disabled", false);
  });
})