<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

/**
 * Returns the importmap for this application.
 *
 * - "path" is a path inside the asset mapper system. Use the
 *     "debug:asset-map" command to see the full list of paths.
 *
 * - "entrypoint" (JavaScript only) set to true for any module that will
 *     be used as an "entrypoint" (and passed to the importmap() Twig function).
 *
 * The "importmap:require" command can be used to add new entries to this file.
 */
return [
    'app' => [
        'path' => './assets/app.js',
        'entrypoint' => true,
    ],
    'ficheAction' => [
        'path' => './assets/fiche-action.js',
        'entrypoint' => true,
    ],
    'listOrder' => [
        'path' => './assets/list-order.js',
        'entrypoint' => true,
    ],
    'presentationDialog' => [
        'path' => './assets/presentation-dialog.js',
        'entrypoint' => true,
    ],
    'questionnaire' => [
        'path' => './assets/questionnaire.js',
        'entrypoint' => true,
    ],
    'htmx' => [
        'path' => './assets/vendor/htmx.min.js',
        'entrypoint' => true,
    ],
    'quill' => [
        'path' => './assets/vendor/quill.js',
    ],
    'quillcss' => [
        'path' => './assets/vendor/quill.snow.css',
        'type' => 'css',
    ],
    'sortable' => [
        'path' => './assets/vendor/Sortable.min.js',
    ],
    'slides' => [
        'path' => './assets/slides.js',
        'entrypoint' => true,
    ],
    'indiceOperateur' => [
        'path' => './assets/indice-operateur.js',
        'entrypoint' => true,
    ],
    'pagePublique' => [
        'path' => './assets/generate-page-publique.js',
        'entrypoint' => true,
    ]
];
