<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Command;

use App\Entity\UserFablogRole;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;
use Symfony\Component\Console\Question\Question;
use Symfony\Component\Console\Question\ChoiceQuestion;
use Symfony\Component\PasswordHasher\Hasher\UserPasswordHasherInterface;
use Symfony\Component\Validator\Validator\ValidatorInterface;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use App\Entity\User;
use App\Entity\UserRole;
use App\Repository\UserRepository;


#[AsCommand(
    name: 'app:new-user',
    description: 'create user for org',
)]
class NewUserCommand extends Command
{

    public function __construct(
        private UserPasswordHasherInterface $userPasswordHasher,
        private UserRepository $userRepository,
        private ValidatorInterface $validator,
    ){
        parent::__construct();
    }
    protected function configure(): void
    {
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $helper = $this->getHelper('question');
        $io = new SymfonyStyle($input, $output);

        $output->writeln([
            '',
            '<info>Création d’un user pour FabLog ICL</info>',
            '',
            '===============================================',
            '',
        ]);

        $question = new Question('Email : ');
        $question->setNormalizer(function ($value) {
            return trim($value);
        });
        $question->setValidator(function ($answer) {
            if ($answer == '' ) {
                throw new \RuntimeException(
                    'Un email por favor :)'
                );
            }
            $errors = $this->validator->validate($answer, new Assert\Email());
            if ($errors->count()) {
                throw new \RuntimeException(
                    'L’email n’est pas valide ...'
                );
            }

            return $answer;
        });
        $email = $helper->ask($input, $output, $question);

        if ($email) {
            $io->info(sprintf('Email : %s', $email));
        }

        $question = new Question('Nom complet : ');
        $question->setNormalizer(function ($value) {
            return trim($value);
        });
        $question->setValidator(function ($answer) {
            if ($answer == '' ) {
                throw new \RuntimeException(
                    'Un nom stp :)'
                );
            }

            return $answer;
        });
        $nom = $helper->ask($input, $output, $question);

        if ($nom) {
            $io->info(sprintf('Nom : %s', $nom));
        }
        $question = new Question('Password : ');
        $question->setNormalizer(function ($value) {
            return trim($value);
        });
        $question->setValidator(function ($answer) {
            if ($answer == '' ) {
                throw new \RuntimeException(
                    'Un pwd stp :)'
                );
            }

            return $answer;
        });
        $password = $helper->ask($input, $output, $question);

        $user = new User();
        $user->setPassword(
            $this->userPasswordHasher->hashPassword(
                $user,
                $password
            )
        );

        $user->setRoles([
            UserFablogRole::ROLE_FABLOG_ADMIN->value,
        ]);

        $user->setFullname($nom);
        $user->setEmail($email);

        $this->userRepository->save($user, true);
        // dd($user);

        $io->success("user créé avec email $email");

        return Command::SUCCESS;
    }
}
