<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Repository\AccountSuppressRepository;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Security\Http\Attribute\IsGranted;

#[AsController]
#[IsGranted('ROLE_FABLOG_ADMIN')]
#[Route('/admin/beneficiaires', name: 'admin_beneficiaires_suppress_account', methods: ['POST'])]
final class AdminAccountSuppressController
{
    public function __construct(
        private UrlGeneratorInterface $urlGenerator,
        private readonly AccountSuppressRepository $accountSuppressRepository,
    )
    {
    }

    public function __invoke(Request $request): RedirectResponse
    {
        $accountsToSuppress =$request->request->all('userId');

        try {
            $this->accountSuppressRepository->removeAccounts($accountsToSuppress);
        } catch (\Exception $e) {
            $request->getSession()->getFlashBag()->add('error', 'Les suppressions ont échoué. Vous pouvez ré-essayer ou contacter le support');
        }

            $request->getSession()->getFlashBag()->add('success', 'Les suppressions ont été effectuées');

        return new RedirectResponse(
            $this->urlGenerator->generate('admin_beneficiaires_list')
        );
    }
}
