<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Repository\DiagnosticCycloDiagRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Twig\Environment;
use Twig\Extra\Intl\IntlExtension;

#[AsController]
#[IsGranted('ROLE_FABLOG_ADMIN')]
#[Route('/admin/diagnostics', name: 'admin_diagnostics_list')]
final class AdminDiagnosticsListController
{
    public function __construct(
        private Environment                 $twig,
        private readonly DiagnosticCycloDiagRepository $diagnosticCycloDiagRepository,
        private MenuBuilder                 $menuBuilder,
    )
    {
    }

    public function __invoke(): Response
    {
        $this->twig->addExtension(new IntlExtension());

        $menu = $this->menuBuilder->buildMenu('Tableau de bord');
        $menu['Tableau de bord']['subMenu']['Diagnostics en cours']['active'] = true;
        $diagsWithComps =  $this->diagnosticCycloDiagRepository->getAllWithStepCompletion();

        return new Response(
            $this->twig->render('admin_dashboard/diagnostics_list.html.twig', [
                'menu' => $menu,
                'diagsWithComps' => $diagsWithComps,
            ])
        );
    }
}
