<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Repository\FicheActionRepository;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;

#[AsController]
#[Route('/admin/fiche-action', name: 'admin_fiche_action_list')]
final class AdminFicheActionListController
{
    public function __construct(
        private Environment $twig,
        private MenuBuilder                 $menuBuilder,
        private FicheActionRepository $ficheActionRepository,
    ){
    }

    public function __invoke(): Response
    {

        $menu = $this->menuBuilder->buildMenu('Fiches Action');
        $menu['Fiches Action']['subMenu']['Liste']['active'] = true;

        $fichesAction = $this->ficheActionRepository->allFicheActionPreview();

        return new Response(
            $this->twig->render('admin_fiche_action/index.html.twig', [
                'menu' => $menu,
                'fichesAction' => $fichesAction,
            ])
        );
    }
}
