<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Repository\FicheActionRepository;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;

#[AsController]
#[Route('/admin/fiche-action/order', name: 'admin_fiche_action_order', methods: ['POST'])]
final class AdminFicheActionOrderController
{
    public function __construct(
        private Environment $twig,
        private FicheActionRepository $ficheActionRepository,
    ){
    }

    public function __invoke(Request $request): Response
    {

        $this->ficheActionRepository->saveOrder($request->request->all('order'));

        $fichesAction = $this->ficheActionRepository->allFicheActionPreview();

        $template = $this->twig->load('admin_fiche_action/index.html.twig');
        return new Response(
            $template->renderBlock('orderForm', [
                'fichesAction' => $fichesAction,
            ])
        );
    }
}
