<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Entity\User;
use App\Form\AdminUserFablogType;
use App\Menu\MenuBuilder;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;

#[AsController]
#[IsGranted('ROLE_SUPER_ADMIN')]
#[Route('/admin/user/new', name:'admin_user_create', methods: ['GET', 'POST'])]
class AdminUserCreateController extends AbstractController
{

    public function __construct(
        private MenuBuilder $menuBuilder,
    ){}
    public function __invoke(Request $request, EntityManagerInterface $entityManager): Response
    {
        $user = new User();
        $form = $this->createForm(AdminUserFablogType::class, $user);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {

            $user->setRoles($request->request->all('admin_user_fablog')['roles']);
            $entityManager->persist($user);
            $entityManager->flush();

            return $this->redirectToRoute('admin_user_list', [], Response::HTTP_SEE_OTHER);
        }

        $menu = $this->menuBuilder->buildMenu('Utilisateurs');
        $menu['Utilisateurs']['subMenu']['Créer']['active'] = true;

        return $this->render('admin_user/new.html.twig', [
            'user' => $user,
            'form' => $form,
            'menu' => $menu,
        ]);
    }
}