<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Repository\UserListRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Twig\Environment;

#[AsController]
#[IsGranted('ROLE_FABLOG_ADMIN')]
#[Route('/admin/user', name: 'admin_user_list')]
final class AdminUserListController
{
    public function __construct(
        private Environment                 $twig,
        private readonly UserListRepository $userListRepository,
        private MenuBuilder                 $menuBuilder,
    )
    {
    }

    public function __invoke(): Response
    {

        $menu = $this->menuBuilder->buildMenu('Utilisateurs');
        $menu['Utilisateurs']['subMenu']['Liste']['active'] = true;

        return new Response(
            $this->twig->render('admin_user/index.html.twig', [
                'usersCommu' => $this->userListRepository->findAllCommunaute(),
                'menu' => $menu,
            ])
        );
    }
}
