<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Questionnaire\QuestionnaireCycloDiag;
use App\Repository\CommuneEPCIRepository;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\ResponseCycloDiagRepository;
use Symfony\Component\HttpFoundation\HeaderUtils;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Serializer\Encoder\CsvEncoder;
use Symfony\Component\Serializer\Encoder\EncoderInterface;
use Twig\Environment;

#[AsController]
#[Route('/commune-epci/export-csv/{diagUuid}', name: 'communeEPCI_export_to_csv')]
final class CommuneEPCIExportCSVController
{


    public function __construct(
        private EncoderInterface              $csvEncoder,
        private ResponseCycloDiagRepository   $responseCycloDiagRepository,
        private DiagnosticCycloDiagRepository $diagRepository,
    )
    {
    }

    public function __invoke(string $diagUuid): Response
    {

        $rows = $this->responseCycloDiagRepository->getExportedResponsesFromDiag($diagUuid);
        $csv = $this->csvEncoder->encode($rows, 'csv', [
            'csv_delimiter' => "\t",
        ]);

        $diag = $this->diagRepository->findOne($diagUuid);
        $response = new Response($csv);

        $disposition = HeaderUtils::makeDisposition(
            HeaderUtils::DISPOSITION_ATTACHMENT,
            $diag->name . '.csv'
        );

        $response->headers->set('Content-Disposition', $disposition);
        return $response;
    }
}
