<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Entity\publicPage;
use App\Repository\CommuneEPCIRepository;
use App\Repository\PublicPageRepository;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

#[AsController]
#[Route('/commune-epci/public-page', name: 'communeEPCI_public_page_generate', methods: ['POST'])]
final class CommuneEPCIGeneratePublicPageController
{

    public function __construct(
        private UrlGeneratorInterface $urlGenerator,
        private CommuneEPCIRepository $communeEPCIRepository,
        private PublicPageRepository  $publicPageRepository,
    )
    {
    }

    public function __invoke(Request $request): RedirectResponse
    {

        $collectiviteId = $request->request->get('collectiviteId');
        $collectiviteMeta = $this->communeEPCIRepository->getMeta($collectiviteId);

        if ($collectiviteMeta['publicPageSlug'] === null) {
            $this->setPublicPageSlug($collectiviteId);
            $collectiviteMeta = $this->communeEPCIRepository->getMeta($collectiviteId);
        }

        $request->request->set('slug', $collectiviteMeta['publicPageSlug']);
        $publicPage = publicPage::fromRequest($request);
        $this->publicPageRepository->save($publicPage);

        $this->communeEPCIRepository->setPageLastVersion($collectiviteId, $publicPage->version());

        $request->getSession()->getFlashBag()->add('success', 'Votre page publique a bien été générée.');

        return new RedirectResponse(
            $this->urlGenerator->generate('communeEPCI_public_page')
        );
    }

    private function setPublicPageSlug(int $collectiviteId)
    {
        $this->communeEPCIRepository->updatePublicPageSlug($collectiviteId);
    }
}
