<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Repository\CommuneEPCIRepository;
use Assert\Assert;
use Assert\AssertionFailedException;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Security\Csrf\CsrfToken;
use Symfony\Component\Security\Csrf\CsrfTokenManagerInterface;
use Twig\Environment;

#[AsController]
#[Route('/commune-epci/presentation', name: 'communeEPCI_save_logo_and_generate_slides', methods: ['POST'])]
final class CommuneEPCIGenerateSlidesController
{


    public function __construct(
        private UrlGeneratorInterface     $urlGenerator,
        private CsrfTokenManagerInterface $csrfTokenManager,
        private CommuneEPCIRepository     $communeEPCIRepository,
    )
    {
    }

    public function __invoke(Request $request): RedirectResponse
    {
        $submittedToken = $request->getPayload()->get('_logo_url_token');

        if (!$this->csrfTokenManager->isTokenValid(new CsrfToken('logo-url', $submittedToken))) {
            $request->getSession()->getFlashBag()->add('error', 'Le jeton CSRF est invalide. Essayez de re-soumettre le formulaire');
        }

        $diagUuid = $request->request->get('diagUuid');
        $logoUrl = $request->request->get('logo-url');

        if ($this->processLogoUrl($logoUrl, $diagUuid) === false) {
            $request->getSession()->getFlashBag()->add('error', 'L’URL fournie pour le logo n’est pas valide');

            return new RedirectResponse(
                $this->urlGenerator->generate('communeEPCI_diagnostics')
            );
        }

        return new RedirectResponse(
            $this->urlGenerator->generate('communeEPCI_show_presentation', [
                'diagUuid' => $diagUuid])
        );
    }

    private function processLogoUrl(string $logoUrl, string $diagUuid)
    {
        if ($logoUrl == '') {

            return true;
        }
        try {
            Assert::that($logoUrl, 'logoUrl')->url()->satisfy(function ($logoUr) {
                $ext = (explode('.', $logoUr));
                $ext = array_pop($ext);
                if (in_array($ext, ['png', 'jpg', 'jpeg'])) {
                    return true;
                }
                return false;
            });
        } catch (AssertionFailedException $e) {

            return false;
        }

        $this->communeEPCIRepository->updateLogoUrl($logoUrl, [
            'diagUuid' => $diagUuid
        ]);

        return true;
    }
}
