<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Questionnaire\PublicPageBuilder;
use App\Repository\CommuneEPCIRepository;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\PublicPageRepository;
use App\Repository\ResponseCycloDiagRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;

#[AsController]
#[Route('/commune-epci/public-page', name: 'communeEPCI_public_page', methods: ['GET'])]
final class CommuneEPCIPublicPageController
{


    public function __construct(
        private Security                      $security,
        private Environment                   $twig,
        private MenuBuilder                   $menuBuilder,
        private DiagnosticCycloDiagRepository $diagnosticCycloDiagRepository,
        private ResponseCycloDiagRepository   $responseCycloDiagRepository,
        private CommuneEPCIRepository         $communeEPCIRepository,
        private PublicPageRepository          $publicPageRepository,
    )
    {
    }

    public function __invoke(): Response
    {
        $navMenu = $this->menuBuilder->buildMenu('Compte');
        $navMenu['Compte']['subMenu']['Page publique']['active'] = true;
        $publicPageInfo = $publicPageContent = '';
        $publicPageVersion = null;

        $user = $this->security->getUser();
        $collectiviteId = $user->getCommuneEPCIId();
        /*
         * if publicPage record exist show it w/ date when last generated + link to re-generate
         * if not find latest diag and generate the preview
         * */

        $collectiviteMeta = $this->communeEPCIRepository->getMeta($collectiviteId);
        if ($collectiviteMeta['publicPageLastVersion'] !== null) {
            $publicPage = $this->publicPageRepository->findLatest($collectiviteMeta['publicPageSlug']);
            $formatedDate = (new \DateTimeImmutable($publicPage->createdAt))->format('j/m/Y');
            $publicPageInfo = <<<HTML
            <h3>Page publique créée le $formatedDate </h3>
            <p>Page visible à ce lien : <a href="/page/{$collectiviteMeta['publicPageSlug']}">/page/{$collectiviteMeta['publicPageSlug']}</a></p>
HTML;
            $publicPageContent = $publicPage->html;
            $publicPageVersion = $publicPage->version();
        }

        $allDiags = $this->diagnosticCycloDiagRepository->findAll($collectiviteId);
        $diagsUuid = array_keys($allDiags);
        $latestDiagUuid = array_shift($diagsUuid);
        $indexedResponses = $this->responseCycloDiagRepository->getValuesVersionForDiag($latestDiagUuid);
        $latestDiagName = reset($allDiags)->name;

        $pageContent = PublicPageBuilder::page($indexedResponses);

        return new Response(
            $this->twig->render('communeEPCI/public_page_preview.html.twig', [
                'menu' => $navMenu,
                'collectiviteMeta' => $collectiviteMeta,
                'publicPageInfo' => $publicPageInfo,
                'publicPageContent' => $publicPageContent,
                'publicPageVersion' => $publicPageVersion,
                'public_page_preview' => $pageContent['page'],
                'toImplement' => $pageContent['notImplemented'],
                'collectiviteId' => $collectiviteId,
                'latestDiagName' => $latestDiagName,
            ])
        );
    }
}
