<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Questionnaire\QuestionInputName;
use App\Questionnaire\QuestionnaireCycloDiag;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;

#[AsController]
#[Route('/commune-epci/request-invite', name: 'communeEPCI_request_invite', methods: ['GET'])]
final class CommuneEPCIRequestInviteController
{
    public function __construct(
        private Environment $twig,
    ){}

    public function __invoke(Request $request): Response
    {
        $questionName = $request->query->get('questionName');
        $questionInputName = QuestionInputName::create($questionName);
        $questionLabel = (new QuestionnaireCycloDiag())->getQuestion($questionInputName)->label;

        return new Response($this->twig->render('communeEPCI/_modal_invite_consultant.html.twig', [
            'questionLabel' => $questionLabel
        ]));
    }
}