<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Menu\MenuBuilder;
use App\Questionnaire\Presentation\SlidesLayout;
use App\Questionnaire\QuestionnaireCycloDiag;
use App\Repository\CommuneEPCIRepository;
use App\Repository\FicheActionRepository;
use App\Repository\ResponseCycloDiagRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;

#[AsController]
#[Route('/commune-epci/presentation/{diagUuid}', name: 'communeEPCI_show_presentation', methods: ['GET'])]
final class CommuneEPCIViewPresentationController
{

    private $prezDir = 'presentations/';

    public function __construct(
        private Environment                 $twig,
        private Security $security,
        private ResponseCycloDiagRepository $responseRepository,
        private FicheActionRepository $ficheActionRepository,
        private CommuneEPCIRepository $communeEPCIRepository,
    ){}

    public function __invoke(string $diagUuid): Response
    {
        return new Response($this->buildHtml($diagUuid));
    }

    private function buildHtml(string $diagUuid)
    {
        // indexed by inputName
        $indexedResponses = $this->responseRepository->getValuesVersionForDiag($diagUuid);

        $indexedFichesActionMemo = $this->ficheActionRepository->allIndexedFicheActionMemo();

        $user = $this->security->getUser();
        $collectiviteId = $user->getCommuneEPCIId();
        $collectiviteMeta = $this->communeEPCIRepository->getMeta($collectiviteId);

        return $this->twig->render('presentation.html.twig', [
            'collectiviteMeta' => $collectiviteMeta,
            'questionnaire' => new questionnaireCycloDiag(),
            'indexedResponses' => $indexedResponses,
            'indexedFichesActionMemo' => $indexedFichesActionMemo,
            'slideLayout' => SlidesLayout::cheminDeFer(),
        ]);

    }

}