<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Entity\User;
use App\Entity\UserWithInviteToken;
use App\Questionnaire\QuestionInputName;
use App\Questionnaire\QuestionnaireCycloDiag;
use App\Questionnaire\QuestionnaireStep;
use App\Repository\InviteTokenRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\DependencyInjection\ParameterBag\ContainerBagInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

#[AsController]
#[Route('/consultant-response/{publicToken}', name: 'consultant_connect_for_response')]
final class ConsultantConnectForResponseController
{
    public function __construct(
        private UrlGeneratorInterface $urlGenerator,
        private InviteTokenRepository $inviteTokenRepository,
        private UserRepository $userRepository,
        private ContainerBagInterface $params,
        private Security $security,
    ){}

    public function __invoke(Request $request, string $publicToken): Response
    {
        if (\strlen($publicToken)  !==  32) {
            $request->getSession()->getFlashBag()->add('warning', 'Le lien n’est pas valide');

            return  new RedirectResponse('/');
        }
        $selector = substr($publicToken,0,8);
        $verifier = substr($publicToken, 8);
        $inviteToken =  $this->inviteTokenRepository->findOneBySelector($selector); // will remove expired tokens

        // verify publicToken
        $isVerified = $inviteToken->verifyPublicToken($verifier, $this->params->get('kernel.secret'));

        if ($isVerified === false) {
            $request->getSession()->getFlashBag()->add('warning', 'Le lien n’est plus valide');

            return  new RedirectResponse('/');
        }

        // login the user
        $user = $this->userRepository->find($inviteToken->userId);
        $this->security->login($user, 'form_login');

        // find step for question
       $questionToRespond = (new QuestionnaireCycloDiag())->getQuestion(
           QuestionInputName::create($inviteToken->questionInputName));
       $stepName = $questionToRespond->getStep()->name;

        // redirect to questionnaire
        return new RedirectResponse(
            $this->urlGenerator->generate('communeEPCI_questionnaire', [
                'stepName' => $stepName,
                'diagUuid' => $inviteToken->diagUuid,
                '_fragment' => (string)$inviteToken->questionInputName
            ])
        );
    }
}
