<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use Symfony\Component\DependencyInjection\ParameterBag\ContainerBagInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Finder\Finder;


#[AsController]
#[Route('/download-source', name: 'download_source_zip')]
final class GitZipDownload
{
    private $finder;
    const ARCHIVE_NAME = 'cyclodiag-latest.tar.gz';

    public function __construct(
        private ContainerBagInterface $params,
    )
    {
        $this->finder = new Finder();
    }

    public function __invoke(Request $request): NotFoundHttpException|BinaryFileResponse
    {
        // the git archive is created when doing a `make update` or `make release` on the prod server
        $gitDir = $this->params->get('kernel.project_dir') . '/gitarchive/';
        $gitArchiveName = self::ARCHIVE_NAME;
        $gitFileName = $gitDir . $gitArchiveName;

        $this->finder->files()->in($gitDir)->name($gitArchiveName);

        if (!$this->finder->hasResults()) {

            throw new NotFoundHttpException('Le fichier demandé n’existe pas');
        }

        $response = new BinaryFileResponse($gitFileName);
        $response->setContentDisposition(ResponseHeaderBag::DISPOSITION_ATTACHMENT, $response->getFile()->getFilename());

        return $response;
    }
}
