<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Repository\CommuneEPCIRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;

#[AsController]
#[Route('/log-gbp-download', name: 'log_gbp_download')]
final class LogGuideBonnePratiqueDownload
{
    public function __construct(
        private Security                $security,
        private readonly UserRepository $userRepository,
    )
    {
    }

    public function __invoke(Request $request): ?Response
    {
        $user = $this->security->getUser();
        if ($user === null) { // this route has no access-control entry defined

            return null;
        }

        $this->userRepository->didDownloadGBP($user->getId());

        return new Response('', 204);
    }
}
