<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Form\RegistrationFormType;
use App\Menu\MenuBuilder;
use App\Repository\CommuneEPCIRepository;
use App\Repository\PublicPageRepository;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Twig\Environment;
use Twig\Extra\Intl\IntlExtension;

#[Route('/page/{slug}', name: 'public_page')]
#[AsController]
final class PublicPageController
{
    public function __construct(
        private Environment           $twig,
        private MenuBuilder           $menuBuilder,
        private PublicPageRepository  $publicPageRepository,
        private CommuneEPCIRepository $communeEPCIRepository,
    )
    {
    }

    public function __invoke(string $slug): Response
    {
        $this->twig->addExtension(new IntlExtension());

        $publicPage = $this->publicPageRepository->findLatest($slug);
        $collectiviteMeta = $this->communeEPCIRepository->getMetaBySLug($slug);

        $navMenu = $this->menuBuilder->publicMenu();
        $navMenu['Page cycloDiag ' . $collectiviteMeta['name']] = [
            'open' => true
        ];

        return new Response(
            $this->twig->render('communeEPCI/public_page.html.twig', [
                'menu' => $navMenu,
                'collectiviteName' => $collectiviteMeta['name'],
                'publicPage' => $publicPage,
            ]));
    }
}
