<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Form\RegistrationFormType;
use App\Menu\MenuBuilder;
use App\Questionnaire\QuestionnaireCycloDiag;
use App\Questionnaire\QuestionnaireStep;
use App\Repository\FicheActionRepository;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Twig\Environment;

#[AsController]
#[Route('/questionnaire/{stepName}', name: 'public_questionnaire')]
final class PublicQuestionnairePreviewController
{
    public function __construct(
        private Environment          $twig,
        private FormFactoryInterface $formFactory,
        private MenuBuilder $menuBuilder,
        private FicheActionRepository $ficheActionRepository,
    )
    {
    }

    public function __invoke(string $stepName = 'CONTEXTE'): Response
    {
        $currentStep = constant('App\Questionnaire\QuestionnaireStep::'.$stepName);
        $questions = [];
        $ficheActionRefs = [];

        $formNbr = 0;
        foreach ((new QuestionnaireCycloDiag())->getQuestionsForStep($currentStep) as $question) {
            $formNbr++;
            $form = $this->formFactory->createNamed('question-' . $formNbr,
                $question->formClass,
                null, [
                    'question_name' => (string)$question->getInputName(),
                    'label' => $question->label,
                    'label_help' => $question->help,
                    'other_option' => $question->otherOption,
                    'attr' => $question->getAttr()
                ]);
            $ficheActionRefs[] = $question->resolveFicheAction();

            $questions[] = [
                'form' => $form->createView(),
                'sectionHead' => $question->sectionHead,
                'stepName' => $question->getStep()->name,
                'ficheActionRef' => $question->resolveFicheAction(),
            ];
        }


        $menu = $this->menuBuilder->buildMenu('Questionnaire');
        $menu = $this->menuBuilder->setSubMenuQuestionnaire($menu);
        // dd($menu);
        foreach ($menu['Questionnaire']['subMenu'] as $menuStep => &$item) {
            $item['active'] = $menuStep === $currentStep->name;
        }

        $registrationForm = $this->formFactory->create(RegistrationFormType::class, null, [
            'action' => '/creer-compte'
        ]);

        $ficheActionPreview = $this->ficheActionRepository->findFicheActionPreviewByRefs($ficheActionRefs);

        return new Response(
            $this->twig->render('public/questionnaire_preview.html.twig', [
                'questions' => $questions,
                'prevNext' => QuestionnaireStep::prevNext($currentStep),
                'menu' => $menu,
                'registrationForm' => $registrationForm->createView(),
                'ficheActionPreview' => $ficheActionPreview,
            ]));
    }
}
