<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Controller;

use App\Form\UserPasswordType;
use App\Menu\MenuBuilder;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Security\Http\Attribute\IsGranted;
use Twig\Environment;

#[AsController]
#[IsGranted('ROLE_USER')]
#[Route('/user/setting', name: 'user_setting')]
final class UserSettingController
{
    public function __construct(
        private Environment           $twig,
        private Security              $security,
        private FormFactoryInterface  $formFactory,
        private UrlGeneratorInterface $urlGenerator,
        private MenuBuilder           $menuBuilder,
    )
    {
    }

    public function __invoke(Request $request, EntityManagerInterface $entityManager): Response|RedirectResponse
    {

        $navMenu = $this->menuBuilder->buildMenu('Mon profil');
        $navMenu['Mon profil']['subMenu']['Changer mot de passe']['active'] = true;

        $user = $this->security->getUser();

        $form = $this->formFactory->create(UserPasswordType::class, $user);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            $request->getSession()->getFlashBag()->add('success', 'Informations mises à jour');
            return new RedirectResponse(
                $this->urlGenerator->generate('user_profile'),
                Response::HTTP_SEE_OTHER
            );
        }

        return new Response(
            $this->twig->render('user_profile/setting.html.twig', [
                'user' => $user,
                'form' => $form->createView(),
                'menu' => $navMenu,
            ]));
    }
}
