<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Entity;

use App\Config\ReminderInterval;

final class CollegueReminderDTO
{
    private function __construct(
        public readonly int $userId,
        public readonly string $fullName ,
        public readonly string $email,
        public readonly string $diagUuid,
        public readonly string $lastResponse,
        public readonly array $qsToRespond,
        public readonly int $qsToRespondCount,
        public readonly int $qsRespondedCount,
        private ?string $sent,
    ){}

    public static function fromDatabaseRecord($row){
        return new self(
            $row['userId'],
            $row['fullName'],
            $row['email'],
            $row['diagUuid'],
            $row['lastResponse'],
            json_decode($row['qsToRespond']),
            $row['qsToRespondCount'],
            $row['qsRespondedCount'],
            $row['sent'],
        );
    }

    public function sent(): ?string
    {
        return $this->sent;
    }

    public function setSent(): void
    {
        $sent = ($this->sent === null) ? ReminderInterval::J7->value : ReminderInterval::J14->value;
        $this->sent = $sent;
    }
}
