<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Entity;


use Symfony\Component\String\Slugger\AsciiSlugger;

class CommuneEPCI
{
    public function __construct(
        private readonly ?int $id,
        private ?string       $name = null,
        private ?string       $region = null,
        private int           $version = 0,
    )
    {}

    public static function create(string $name, string $region): self
    {
        return new self(
            null,
            $name,
            $region,
        );
    }

    public function toDatabaseRecord(): array
    {
        return [
            'name' => $this->name,
            'region' => $this->region,
            'version' => $this->version,
        ];
    }

    public static function fromDatabaseRecord(array $row): self
    {
        return new self(
            $row['id'],
            $row['name'],
            $row['region'],
            $row['version'],
        );
    }

    public function id()
    {
        return $this->id;
    }

    public static function tableName(): string
    {
        return 'communeEPCI';
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function getRegion(): ?string
    {
        return $this->region;
    }

    public function sluggedName(): string
    {
        $slugger = new AsciiSlugger();
        return $slugger->slug($this->name);
    }

}
