<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Entity;

class DiagnosticCycloDiag
{
    /*
  uuid varchar(36) [pk]
  communeEPCI_id int
  ownerId int [note: 'user who started the questionnaire']
  duplicatedFrom varchar(36) [note: 'diagnosticCycloDiag.uuid']
  name  varchar(256)
  version int
  createdAt datetime
  updatedAt datetime
     * */

    public function __construct(
        public readonly string $uuid,
        public readonly int    $communeEPCI_id,
        public readonly int    $ownerId,
        public readonly string $name,
        public readonly int    $version = 0,
        private ?string        $duplicatedFrom = null,
    )
    {
    }

    public static function create(array $data): self
    {
        return new self(
            $data['uuid'],
            $data['communeEPCI_id'],
            $data['ownerId'],
            $data['name'],
        );
    }

    public function setDuplicated(string $uuid){
        $this->duplicatedFrom = $uuid;
    }

    public static function fromDbRecord(array $row)
    {
        return new self(
            $row['uuid'],
            $row['communeEPCI_id'],
            $row['ownerId'],
            $row['name'],
            $row['version'],
            $row['duplicatedFrom'],
        );
    }

    public function toDbRecord(): array
    {
        return [
            'uuid' => $this->uuid,
            'communeEPCI_id' => $this->communeEPCI_id,
            'ownerId' => $this->ownerId,
            'duplicatedFrom' => $this->duplicatedFrom,
            'name' => $this->name,
            'version' => $this->version,
        ];
    }

    public function identifier(): array
    {
        return [
            'uuid' => $this->uuid,
        ];
    }

    public static function params()
    {
        return [
            \PDO::PARAM_STR,
            \PDO::PARAM_INT,
            \PDO::PARAM_INT,
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_INT,
        ];
    }

    public static function tableName(): string
    {
        return 'diagnosticCycloDiag';
    }
}