<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Entity;

use App\Questionnaire\QuestionInputName;
use Symfony\Component\Mime\Exception\InvalidArgumentException;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Mime\Address;
use Symfony\Component\Mime\Email;

class InviteConsultantRequestDTO
{
    private function __construct(
        private Address $consultantNameEmail,
        private string $diagUuid,
        private QuestionInputName $questionInputName,
    ){}

    public static function fromRequest(Request $request):self
    {
        $consultantNameEmail = '';
        $emailAddress = $request->request->get('consultantNameEmail') ?? throw new \OutOfBoundsException('il manque le mail');
        $diagUuid = $request->request->get('diagUuid') ?? throw new \OutOfBoundsException('il manque la valeur : diagUuid ');
        $questionInputName = $request->request->get('questionInputName') ?? throw new \OutOfBoundsException('il manque la valeur : questionInputName');

        try {
            $consultantNameEmail = Address::create($emailAddress);
        } catch (InvalidArgumentException $e){
            throw new \Exception(sprintf(
            'Impossible de créer un compte avec l’adresse %s', $emailAddress));
        }

        return new self(
            $consultantNameEmail,
            $diagUuid,
            QuestionInputName::create($questionInputName),
        );
    }

    public function getConsultantName(): string
    {
        return $this->consultantNameEmail->getName();
    }
    public function getConsultantEmail(): string
    {
        return $this->consultantNameEmail->getAddress();
    }

    public function getDiagUuid(): string
    {
        return $this->diagUuid;
    }

    public function getQuestionInputName(): string
    {
        return $this->questionInputName;
    }


}