<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Entity;

use App\Questionnaire\QuestionInputName;
use App\Questionnaire\QuestionnaireStep;
use Symfony\Component\HttpFoundation\Request;

final class ResponseCycloDiag_DTO
{
    const PRECISER = 'Preciser'; // used by NoYesSpecifyType|YesNoOtherType AND 'otherOption'

    public function __construct(
        public readonly string $diagUuid,
        public readonly string $inputName,
        public readonly string $stepName,
        private mixed          $value = '',
        private mixed          $other = null,
        private ?int           $version = null,
    )
    {
    }

    public static function create(string $diagUuid, QuestionInputName $inputName, QuestionnaireStep $step): self
    {
        return new self(
            $diagUuid,
            (string)$inputName,
            $step->name,
        );
    }

    public static function fromRequest(Request $request): self
    {
        /*
        dd($request->request->keys());
        array:3 [▼
          0 => "question-4"
          1 => "questionInputName"
          2 => "diagUuid"
        ]

         dd($request->request->all());
         array:3 [▼
          "question-4" => array:2 [▼
            "contexte-i-population" => "15222"
            "_token" => "a0525e.pWd1CAzFUJhzy26TzVf_A206IHZ0B7zWPxnAB0QUGeE.wh8-RHbxJ6gKuVzU-SbOOilCTRc_StmxS360XTFmKK71DD9tbZA4rUX7Kw"
          ]
          "questionInputName" => "contexte-i-population"
          "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea"
        version
        ]*/
        $formName = $request->request->keys()[0];
        $questionInputName = $request->request->get('questionInputName') ?? throw new \OutOfBoundsException('il manque la valeur : questionInputName');
        $stepName = $request->request->get('stepName') ?? throw new \OutOfBoundsException('il manque la valeur : step');
        $value = $request->request->all($formName)[$questionInputName] ?? throw new \OutOfBoundsException('il manque la valeur : value ');
        $other = $request->request->all($formName)[self::PRECISER] ?? null;

        return new self(
            $request->request->get('diagUuid') ?? throw new \OutOfBoundsException('il manque la valeur : diagUuid '),
            $questionInputName,
            $stepName,
            $value,
            $other,
            (int)$request->request->get('questionVersion') ?? null,
        );
    }

    public function setValue(mixed $value): void
    {
        $this->value = $value;
    }

    public function getValue(): string
    {
        return $this->value;
    }

    public function version() {
        return $this->version;
    }

    public function toDBRecord(): array
    {
        $this->version = ($this->version === null) ? 0 : ++$this->version;

        return [
            'diagUuid' => $this->diagUuid,
            'inputName' => $this->inputName,
            'step' => $this->stepName,
            'value' => $this->value,
            'other' => $this->other,
            'version' => $this->version,
        ];
    }

    public static function fromDBRecord(array $row): self
    {
        return new self(
            $row['diagUuid'],
            $row['inputName'],
            $row['step'],
            $row['value'],
            $row['other'],
            $row['version'],
        );
    }

    public function identifier(): array
    {
        return [
            'diagUuid' => $this->diagUuid,
            'inputName' => $this->inputName,
        ];
    }

    public static function params()
    {
        return [
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_INT,
        ];
    }

    public static function tableName(): string
    {
        return 'reponseCycloDiag';
    }

    public function getOther(): mixed
    {
        return $this->other;
    }

    public function setOther(mixed $other): void
    {
        $this->other = $other;
    }
}
