<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\EventListener;

use App\Questionnaire\QuestionnaireStep;
use App\Repository\DiagnosticCycloDiagRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
use Symfony\Component\Security\Http\Event\LoginSuccessEvent;

class LoginSuccessListener
{
    public function __construct(
        private Security $security,
        private UrlGeneratorInterface $urlGenerator,
        private DiagnosticCycloDiagRepository $diagnosticCycloDiagRepository,
    )
    {
    }

    public function __invoke(LoginSuccessEvent $event)
    {
        $user = $event->getUser();

        if ($this->security->isGranted('ROLE_BENEFICIAIRE', $user)){
            $collectiviteId = $user->getCommuneEPCIId();
            $diagUuid = $this->diagnosticCycloDiagRepository->findLatestUuidForCommune($collectiviteId);

            $response = new RedirectResponse(
                $this->urlGenerator->generate('communeEPCI_questionnaire', [
                    'stepName' => QuestionnaireStep::CONTEXTE->name,
                    'diagUuid' => $diagUuid
                ])
            );
        } elseif ($this->security->isGranted('ROLE_FABLOG_ADMIN', $user)){
            $response = new  RedirectResponse(
                $this->urlGenerator->generate('admin_diagnostics_list')
            );

        } else {
            $response = new RedirectResponse(
                $this->urlGenerator->generate('fiche_action')
            );
        }

        $event->setResponse($response);
    }
}