<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Form;

use App\Entity\FicheAction;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\NotBlank;

class FicheActionType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('reference', TextType::class, [
                'label' => 'reference',
                'required' => true,
            ])
            ->add('slug', TextType::class, [
                'label' => 'texte de l’URL(laisser blanc si vous ne savez pas)',
                'required' => false
            ])
            ->add('title', TextType::class, [
                'label' => 'titre',
                'required' => false,
            ])
            ->add('theme', ChoiceType::class, [
                'label' => 'thématique',
                'choices' => [
                    'Aide à l’investissement' => 'Aide à l’investissement',
                    'Aménagement du territoire' => 'Aménagement du territoire',
                    'Foncier' => 'Foncier',
                    'Portage politique' => 'Portage politique',
                ],
                'placeholder' => 'Aucun',
                'required' => false,
                'expanded' => true,
                'multiple' => false,
            ])
            ->add('content', TextareaType::class, [
                'label' => 'contenu',
                'required' => false,
            ])
            ->add('preview', TextareaType::class, [
                'label' => 'synthèse'
            ])
            ->add('viewOrder', HiddenType::class)
            ->add('version', HiddenType::class, [
                'label' => 'version'
            ]);
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
//            'data_class' => FicheAction::class,
            'csrf_protection' => true,
            'csrf_field_name' => '_token',
            'csrf_token_id' => 'fiche_action_token',
            'allow_extra_fields' => true,
        ]);
    }
}
