<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Menu;

use App\Config\navMenu;
use App\Entity\UserFablogRole;
use App\Questionnaire\QuestionnaireStep;
use App\Repository\FicheActionRepository;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

class MenuBuilder
{
    private string $userRole;

    private array $navMenu;

    public function __construct(
        private Security              $security,
        private UrlGeneratorInterface $urlGenerator,
        private FicheActionRepository $ficheActionRepository,
    )
    {
    }

    public function buildMenu(?string $activeTopLevel = null): array
    {
        $this->navMenu = $this->menuFromRole();

        if ($activeTopLevel) {
            $this->navMenu[$activeTopLevel]['open'] = true;
        }

        return $this->navMenu;
    }

    public function publicMenu(): array
    {
        $this->navMenu = navMenu::menu('PUBLIC_ACCESS');

        return $this->navMenu;
    }

    private function menuFromRole(): array
    {
        $user = $this->security->getUser();

        if ($user === null) {
            $this->userRole = 'PUBLIC_ACCESS';

            return navMenu::menu($this->userRole);
        }


        foreach (navMenu::menuRoleKeys() as $role) {
            if ($this->security->isGranted($role)) {
                $this->userRole = $role;

                $navMenu = navMenu::menu($this->userRole);
                $navMenu['Mon profil']['subMenu'] = [
                    $user->getFullname() => ''
                ] + $navMenu['Mon profil']['subMenu'];

                return $navMenu;
            }
        }
    }

    public function setSubMenuQuestionnaire(array $menu): array
    {
        $menuLink = [];

        foreach (QuestionnaireStep::array() as $stepName => $label) {
            $menuLink = [
                'path' => $this->urlGenerator->generate('public_questionnaire', [
                    'stepName' => $stepName,
                ]),
                'label' => $label,
            ];
            // subMenu is an indexed array so we can set 'active' on the proper step
            $menu['Questionnaire']['subMenu'][$stepName] = $menuLink;
        }

        return $menu;
    }

    public function setSubMenuGBP(array $menu): array
    {
        $ficheActionSubMenu = [];
        foreach ($this->ficheActionRepository->allFicheActionForMenu() as $ficheActionMenuLink) {
            $ficheActionSubMenu[] = [
                'path' => $this->urlGenerator->generate(
                    'fiche_action', ['_fragment' => $ficheActionMenuLink->path]),
                'label' => $ficheActionMenuLink->label,
            ];

        }
        $menu['Guide des Bonnes Pratiques']['subMenu'] = $ficheActionSubMenu;

        return $menu;
    }
}