<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Questionnaire\Form;

use App\Entity\ResponseCycloDiag_DTO;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class CommuneEPCIType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $ficheActionShow = ($options['ficheActionRef']) ? '<button type=button class="fablog-btn show-fa-btn"  data-click=showFA data-fa-ref="'.$options['ficheActionRef'].'" title="fiche action correspondante"><svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 16 16"><use href="#three-dash" fill="#486581" x="0" y="0"/><use href="#icon-bubble" fill="#486581" x="0" y="0"/></svg></button>
' : '';
        $builder
            ->add($options['question_name'], ChoiceType::class, [
                'label' => $options['label'].$ficheActionShow,
                'label_html' => true,
                'choices' => [
                    'Commune' => 'Commune',
                    'EPCI (Établissement public de coopération intercommunale)' => 'EPCI',
                ],
                'attr' => ['class' => 'input-grid'],
                'required' => true,
                'expanded' => true,
                'multiple' => false,
                'getter' => function (ResponseCycloDiag_DTO $response, FormInterface $form): string {
                    return $response->getValue();
                }
            ]);
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'question_name' => '',
            'other_option' => '',
            'label_help' => '',
            'ficheActionRef' => '',
        ]);
    }
}