<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Questionnaire;

use Closure;
use OutOfBoundsException;

final class Question
{

    # [Immutable] 
    private readonly QuestionInputName $questionInputName;

//    private string $value;

    private function __construct(
        private readonly QuestionnaireStep $step,
        public readonly ?string            $sectionHead,
        string                             $question_input_name,
        public readonly string             $label,
        public readonly ?string            $help,
        public readonly ?string            $otherOption,
        private array              $attr,
        public readonly string             $formClass,
        private readonly string            $ficheActionRef,
//        private string                     $value,
    )
    {
        $this->questionInputName = QuestionInputName::create($question_input_name);
//      $this->value = $value;
    }

    public static function fromArray(array $data): self
    {
        $formClass = $data['formClass'] ?? throw new OutOfBoundsException('formClass manquant');
        if (!class_exists($formClass)) {
            throw new OutOfBoundsException("$formClass is not defined");
        }
        return new self(
            $data['step'] ?? throw new OutOfBoundsException('step manquant'),
            $data['sectionHead'] ?? null,
            $data['question_input_name'] ?? throw new OutOfBoundsException('question_input_name missing'),
            $data['label'] ?? throw new OutOfBoundsException('label manquant'),
            $data['help'] ?? null,
            // case "Autre (veuillez préciser)" -> textarea input_name:diagnostic-reglementaire-circulation
            $data['otherOption'] ?? null,
            $data['attr'] ?? [],
            $formClass,
            $data['ficheActionRef'] ?? '',
            $data['value'] ?? '',
        );
    }

    public function getInputName()
    {
        return $this->questionInputName;
    }

    public function getStep()
    {
        return $this->step;
    }

    public function formatLabel()
    {
        return str_replace(['<b>','</b>','<strong>','</strong>'],[''], $this->label);
    }

    public function resolveFicheAction(): string
    {
        return $this->ficheActionRef;
    }


    public function getAttr(): array
    {
        return $this->attr;
    }
    public function addAttr(array $attr) {
        $this->attr = array_merge($this->attr, $attr);
    }

}
