<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Questionnaire;

use InvalidArgumentException;

final class QuestionInputName
{
  
  /*
  <diagnostic_step>-<step_chapter>-<question_name> 
  diagnostic-foncier-espace_lgtq
  all lowercase.
  composed word: snake case
   */
  private string $inputName;

  private function __construct(string $inputName)
  {
    if ($inputName !== strtolower($inputName)) {
      throw new InvalidArgumentException("Tous les caractères doivent être en minuscule", 1);
    }

    if (!preg_match('/(\w+)-\w+-\w+/', $inputName, $chunks)) {
      throw new InvalidArgumentException(
        sprintf(
          "%s ne correspond pas au motif <diagnostic_step>-<step_chapter>-<question_name>", $inputName));
    }

    if (! in_array(strtoupper($chunks[1]), QuestionnaireStep::names())) {
        throw new InvalidArgumentException(
            sprintf("%s n’est pas une étape définie dans QuestionnaireStep", $inputName)
        );
    }

    $this->inputName = $inputName;
  }

  public static function create(string $inputName): self {
    return new self($inputName);
  }

  public function __toString(): string
  {
    return (string) $this->inputName;
  }
}

