<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Repository;


class ConcurrentUpdateOccurred extends \RuntimeException
{
    public static function ofEntity($entity): ConcurrentUpdateOccurred
    {
        return new self(sprintf(
            'A concurrent update occurred of an entity of type "%s" with identifier: %s',
            get_class($entity),
            self::renderIdentifier($entity->identifier())
        ));
    }

    /**
     * @param array<string, mixed> $identifier
     */
    private static function renderIdentifier(array $identifier): string
    {
        $parts = [];

        foreach ($identifier as $columnName => $value) {
            $parts[] = $columnName . ' = ' . var_export($value, true);
        }

        return implode(', ', $parts);
    }

}