<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Repository;

use App\Entity\IndiceOperateur;
use Doctrine\DBAL\Connection;

class IndiceOperateurRepository
{
    public function __construct(
        private Connection $connection,
    )
    {
    }

    public function save(IndiceOperateur $indiceOperateur)
    {
        $record = $indiceOperateur->toDBRecord();
        $this->connection->insert('indiceOperateurs', $record, IndiceOperateur::params());
    }

    public function findAllByCollectivite(int $collectiviteId)
    {
        return $this->connection->fetchAllAssociative("
        SELECT * FROM indiceOperateurs WHERE collectiviteId = ? ORDER BY createdAt DESC", [
            $collectiviteId
        ], [
            \PDO::PARAM_INT
        ]);
    }

    public function findAllSorted()
    {
        return $this->connection->fetchAllAssociative("
        SELECT * FROM indiceOperateurs ORDER BY collectiviteId, createdAt DESC");
    }


}