<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Repository;

use App\Entity\publicPage;
use Doctrine\DBAL\Connection;

class PublicPageRepository
{

    public function __construct(
        private Connection $connection,
    )
    {
    }

    public function findLatest(string $slug)
    {
        $row = $this->connection->fetchAssociative(<<<SQL
        SELECT * FROM publicPage 
        WHERE slug = ?
        ORDER BY version DESC
        LIMIT 1
SQL, [
            $slug], [
            \PDO::PARAM_STR
        ]);
        if ($row !== false) {

            return publicPage::fromDB($row);
        }

        return false;
    }

    public function save(publicPage $page) {
        $this->connection->insert('publicPage', $page->toDBRecord(),[
            \PDO::PARAM_STR,
            \PDO::PARAM_STR,
            \PDO::PARAM_INT,
            \PDO::PARAM_STR,
        ]);
    }
}