<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Repository;


use App\Config\ReminderInterval;
use App\Entity\BeneficiaireAdminReminderDTO;
use App\Entity\CollegueReminderDTO;
use Doctrine\DBAL\Connection;
use Doctrine\DBAL\Exception\UniqueConstraintViolationException;

class ReminderLogRepository
{
    public function __construct(
        private Connection $connection,
    ){}

    public function delete(int $userId): void
    {
        $this->connection->delete(
            'reminderLog', [
            'userId' => $userId
        ], [
                \PDO::PARAM_INT
            ]
        );
    }

    public function save(BeneficiaireAdminReminderDTO|CollegueReminderDTO $userReminder): void
    {
        try {
            $this->connection->insert('reminderLog', [
                'userId' => $userReminder->userId,
                'sent' => $userReminder->sent(),
            ], [
                \PDO::PARAM_INT,
                \PDO::PARAM_STR,
            ]);
        } catch (UniqueConstraintViolationException $e) { // this is an update
            /* We might run into this case when
            a diagnostic has not been updated for a long time
            and no command app:remind-beneficiaire was run
            let update silently to longest ReminderInterval
             * */
            $this->update($userReminder);
        }
    }

    public function getAll(): array
    {
        return $this->connection->fetchAllAssociative("
        SELECT * FROM reminderLog");
    }

    private function update(BeneficiaireAdminReminderDTO|CollegueReminderDTO $userReminder)
    {
        $this->connection->update('reminderLog', [
            'sent' => $userReminder->sent(),
        ], [
            'userId' => $userReminder->userId,
        ]);
    }
}
