<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Repository;

use App\Entity\UserBeneficiaireRole;
use App\Entity\UserFablogRole;
use App\ViewDTO\AdminListUser;
use Doctrine\DBAL\Connection;

class UserListRepository
{
    public function __construct(
        private Connection $connection,
    )
    {
    }

    public function findAllCommunaute()
    {
        $whereRoles = array_map(function ($role){
            return <<<SQL
                JSON_CONTAINS(roles, '"$role"')
SQL;
        }, UserFablogRole::values());
        $whereRoles = implode(' OR ', $whereRoles);
        $rows = $this->connection->fetchAllAssociative(<<<SQL
            SELECT u.id, fullName, email, roles, NULL AS communeEPCI
            FROM user u
            WHERE archivedAt IS NULL
                AND ( $whereRoles )
            ORDER BY u.createdAt DESC
SQL
        );

//        https://speakerdeck.com/afilina/avoid-costly-framework-upgrades?slide=63
        $users = array_map(function (array $row){
            return AdminListUser::fromRow($row);
        }, $rows);

        return $users;
    }

    public function findAllBeneficiaires()
    {
        $whereRoles = array_map(function ($role){
            return <<<SQL
                JSON_CONTAINS(roles, '"$role"')
SQL;
        }, UserBeneficiaireRole::values());
        $whereRoles = implode(' OR ', $whereRoles);
        $rows = $this->connection->fetchAllAssociative(<<<SQL
            SELECT u.id, fullName, email, roles, c.name AS communeEPCI
            FROM user u
            LEFT OUTER JOIN communeEPCI c on c.id = u.communeEPCI_id
            WHERE u.archivedAt IS NULL
                AND ( $whereRoles )
            ORDER BY u.createdAt DESC
SQL
        );

        $users = array_map(function (array $row){
            return AdminListUser::fromRow($row);
        }, $rows);

        return $users;
    }

    public function getAllDownloadsByCollectivite()
    {
        return $this->connection->fetchAllAssociative(<<<SQL
            SELECT count(*) as nbrDownload, MAX(u.GBPlastDownloadedAt) as lastDownloadedAt, COALESCE(name, 'Communauté Fablog') as collectivite, region, c.id
                FROM user u
                    LEFT OUTER JOIN communeEPCI c
                        ON c.id = u.communeEPCI_id
                WHERE u.GBPlastDownloadedAt IS NOT NULL
                GROUP BY c.id, c.createdAt
                ORDER BY c.createdAt DESC, collectivite 
            SQL);
    }


}
