<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Security;

use App\Entity\DiagnosticCycloDiag;
use App\Entity\User;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Authorization\Voter\Voter;

class DiagnosticVoter extends Voter
{

    const RESPOND = 'respond';
    const VIEW = 'view';

    /**
     * @inheritDoc
     */
    protected function supports(string $attribute, mixed $subject): bool
    {
        // if the attribute isn't one we support, return false
        if (!in_array($attribute, [self::VIEW, self::RESPOND])) {
            return false;
        }

        // only vote on `Post` objects
        if (!$subject instanceof DiagnosticCycloDiag) {
            return false;
        }

        return true;
    }

    /**
     * @inheritDoc
     */
    protected function voteOnAttribute(string $attribute, mixed $subject, TokenInterface $token): bool
    {
        $user = $token->getUser();

        if (!$user instanceof User) {
            // the user must be logged in; if not, deny access
            return false;
        }

        // you know $subject is a Post object, thanks to `supports()`
        /** @var DiagnosticCycloDiag $diag */
        $diag = $subject;

        return match($attribute) {
            self::VIEW => $this->canView($diag, $user),
            self::RESPOND => $this->canRespond($diag, $user),
            default => throw new \LogicException('This code should not be reached!')
        };
    }

    private function canRespond(DiagnosticCycloDiag $diag, User $user): bool
    {

        return $user->getCommuneEPCIId() === $diag->communeEPCI_id ;
    }

    private function canView(DiagnosticCycloDiag $diag, User $user): bool
    {
        return true;
    }


}