<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\Validator;

use App\Repository\FicheActionRepository;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

class UniqueReferenceValidator extends ConstraintValidator
{
    public function __construct(
        private FicheActionRepository $ficheActionRepository,
    )
    {
    }

    public function validate(mixed $value, Constraint $constraint): void
    {
        if (!$constraint instanceof UniqueReference) {
            throw new UnexpectedTypeException($constraint, UniqueReference::class);
        }

        // custom constraints should ignore null and empty values to allow
        // other constraints (NotBlank, NotNull, etc.) to take care of that
        if (null === $value || '' === $value) {
            return;
        }

        if(!$this->ficheActionRepository->isReferenceInUse($value)) {
            return;
        }

        // the argument must be a string or an object implementing __toString()
        $this->context->buildViolation($constraint->notUniqueReference)
            ->setParameter('{{ reference }}', $value)
            ->addViolation();
    }
}