<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\ViewDTO;

use App\Questionnaire\QuestionInputName;
use App\Questionnaire\QuestionnaireCycloDiag;

class ConsultantQuestion
{
    private static ?QuestionnaireCycloDiag $questionnaire = null;

    public function __construct(
        public readonly ?string  $fullName,
        public readonly ?string  $email,
        public readonly string  $questionLabel,
        public readonly ?string $respondedAt,
    )
    {
    }

    public static function fromRow(array $row): self
    {
        $questionLabel = self::questionnaire()->getQuestion(QuestionInputName::create($row['questionInputName']))->label;
        return new self(
            $row['fullName'],
            $row['email'],
            $questionLabel,
            $row['respondedAt'],
        );
    }

    private static function questionnaire(): QuestionnaireCycloDiag
    {
        if (self::$questionnaire !== null) {
            return self::$questionnaire;
        }

        self::$questionnaire = new QuestionnaireCycloDiag();
        return self::$questionnaire;
    }

}