<?php
/*
 * Copyright 2024 Aleth Gueguen <conseil@alethgueguen.com>
 *  This file is part of CycloDiag.
 *
 * CycloDiag is free software: you can redistribute it and/or modify it under the terms of the GNU Affero General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * CycloDiag is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License along with CycloDiag. If not, see <https://www.gnu.org/licenses/>
 *
 */

namespace App\ViewDTO;

final class DiagnosticForDashboard
{
    public function __construct(
        public readonly string  $uuid,
        public readonly string  $communeEPCI,
        public readonly string  $region,
        public readonly string  $ownerName,
        public readonly string  $lastUpdated,
        public readonly ?string $duplicatedFrom,
        public readonly string  $diagName,
        public readonly string  $completionsByStep,
    )
    {
    }


    public static function fromDbRecord(array $row)
    {
        return new self(
            $row['uuid'],
            $row['commune_EPCI'],
            $row['region'],
            $row['ownerName'],
            $row['lastUpdated'],
            $row['duplicatedFrom'],
            $row['diagName'],
            self::formatCompletionsByStep($row['completionsByStep']),
        );
    }

    private static function formatCompletionsByStep(string $completionsByStep): string
    {
        $decoded = json_decode($completionsByStep, true);
        /* [
                ["step" => "DIAGNOSTIC", "comp" => 6],
                ["step" => "GOUVERNANCE", "comp" => 2],
                ["step" => "CONCERTATION", "comp" => 1],
                ["step" => "IMPLEMENTATION", "comp" => 2]
            ]
         */

        $completionsBySteps = array_map(function ($stepComp) {
            return '<span>' . ucfirst(strtolower($stepComp['step'])) . ' : </span><span class="step-comp">' . $stepComp['comp'] . '</span>';
        }, $decoded);

        return implode('<br>', $completionsBySteps);
    }

}
