<?php

namespace App\Tests\Command;

use App\Entity\DiagnosticCycloDiag;
use App\Entity\InviteConsultantToken;
use App\Entity\ResponseCycloDiag_DTO;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\InviteTokenRepository;
use App\Repository\ReminderLogRepository;
use App\Repository\ResponseCycloDiagRepository;
use App\Repository\UserReminderRepository;
use Symfony\Bundle\FrameworkBundle\Console\Application;
use Symfony\Bundle\FrameworkBundle\Test\KernelTestCase;
use Symfony\Component\Console\Tester\CommandTester;

class RemindBeneficiaireCommandTest extends KernelTestCase
{
    private Application $app;
    private InviteTokenRepository $inviteTokenRepository;
    private DiagnosticCycloDiagRepository $diagRepository;
    private ResponseCycloDiagRepository $responseRepo;
    private ReminderLogRepository $reminderLogRepo;
    private UserReminderRepository $userReminderRepo;
    private $diagUuid = '6648a5fa-eb0f-4629-8283-6e5b6c4611ea';

    protected function setup(): void
    {
        self::bootKernel();
        $this->app = new Application(self::$kernel);

        $this->diagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $this->responseRepo = static::getContainer()->get(ResponseCycloDiagRepository::class);
        $this->reminderLogRepo = static::getContainer()->get(ReminderLogRepository::class);
        $this->userReminderRepo = static::getContainer()->get(UserReminderRepository::class);
        $this->inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
    }

    public function testExecuteForAdmin(): void
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-10 day'));
        $responseToTest = ResponseCycloDiag_DTO::fromDBRecord([
            'diagUuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'inputName' => 'diagnostic-reglementaire-circulation-perimetre',
            'step' => 'DIAGNOSTIC',
            'value' => 789456123000,
            'other' => null,
            'version' => 0
        ]);
        $this->responseRepo->save($responseToTest);

        $command = $this->app->find('app:remind-beneficiaire');
        $commandTester = new CommandTester($command);
        $commandTester->execute([
            'beneficiaire' => 'admin',
        ]);

        $commandTester->assertCommandIsSuccessful();
        $this->assertEmailCount(1);
        // the output of the command in the console
        $output = $commandTester->getDisplay();
    }

    public function testExecuteForCollegue(): void
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-7 day'));

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109, // martin dupont
          'diagUuid' => $this->diagUuid,
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $this->inviteTokenRepository->save($inviteConsultantToken);

        $command = $this->app->find('app:remind-beneficiaire');
        $commandTester = new CommandTester($command);
        $commandTester->execute([
            'beneficiaire' => 'collegue',
        ]);

        $commandTester->assertCommandIsSuccessful();
        $this->assertEmailCount(1);
        // the output of the command in the console
        $output = $commandTester->getDisplay();
    }
}
