<?php

namespace App\Tests\Controller;

use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class AdminFicheActionCreateControllerTest extends WebTestCase
{
    public function testThatNoDataThrows(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $testUser = $userRepository->findOneByEmail('admin@fablog.io');
        $client->loginUser($testUser);

        $crawler = $client->request('POST', '/admin/fiche-action/new', [
        ]);
//        dd($client->getResponse());

        $this->assertResponseIsUnprocessable();
        $this->assertSelectorExists('.alert.flash-error');
        // first alert is for invalid csrf token
        $this->assertSelectorTextContains('.alert.flash-error:nth-child(2)', 'Il manque la reference');
    }

    public function testThatViewOrderHasValue(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $testUser = $userRepository->findOneByEmail('admin@fablog.io');
        $client->loginUser($testUser);

        $client->request('GET', '/admin/fiche-action/new');
        $this->assertResponseIsSuccessful();
        $this->assertSelectorExists('input[type="hidden"][name="viewOrder"][value="4"]');
    }


    public function testThatBlankRequestDoesNotValidate(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $testUser = $userRepository->findOneByEmail('admin@fablog.io');
        $client->loginUser($testUser);

        $client->request('GET', '/admin/fiche-action/new');
        $crawler = $client->submitForm('submit', [
            'reference' => '',
            'theme' => '',
            'preview' => '',
            'title' => '',
            'content' => '',
            'viewOrder' => '',
            'version' => '',
        ]);

//        dd($client->getResponse());

        $this->assertResponseIsUnprocessable();
        $this->assertSelectorExists('.alert.flash-error');
        $this->assertSelectorTextContains('.alert.flash-error', 'The following 2 assertions failed');
    }

    public function testThatReferenceIsUnique(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $testUser = $userRepository->findOneByEmail('admin@fablog.io');
        $client->loginUser($testUser);

        $client->request('GET', '/admin/fiche-action/new');
        $crawler = $client->submitForm('submit', [
            'reference' => 'diag-dispo',
            'theme' => '',
            'preview' => 'azerttip',
            'title' => '',
            'content' => '',
            'viewOrder' => 1,
            'version' => 0,
        ]);

//        dd($client->getResponse());

        $this->assertResponseIsUnprocessable();
        $this->assertSelectorExists('.alert.flash-error');
        $this->assertSelectorTextContains('.alert.flash-error', 'La référence "diag-dispo" pour cette fiche action existe déjà');
    }

}
