<?php

namespace App\Tests\Controller;

use App\Entity\DiagnosticCycloDiag;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\KernelBrowser;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class CommuneEPCIDuplicateDiagControllerTest extends WebTestCase
{
    private KernelBrowser $client;
    private $diagUuid;
    private DiagnosticCycloDiagRepository $diagRepository;
    private UserRepository $userRepository;
    public function setUp(): void
    {
        $this->diagUuid = '6648a5fa-eb0f-4629-8283-6e5b6c4611ea';
        $this->client = static::createClient();
        $this->diagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $this->userRepository = static::getContainer()->get(UserRepository::class);
    }

    public function testThatNotCompleteDiagWillReturnModal(): void
    {

        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $testUser = $this->userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $this->client->loginUser($testUser);

        $crawler = $this->client->request('POST', '/commune-epci/duplicate-diag', [
              "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
        ],[],[
            // real header is HX-Request see :
            // https://symfony.com/doc/current/testing.html#sending-custom-headers
            'HTTP_HX_REQUEST' => true
        ]);
//dd($this->client->getResponse()->getContent());
        $this->assertResponseIsSuccessful();
        $this->assertSelectorExists('dialog#confirm-duplicate');
    }

    public function testThatConfirmDuplicateWillDuplicatesDiag(): void
    {

        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $testUser = $this->userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $this->client->loginUser($testUser);

        $crawler = $this->client->request('POST', '/commune-epci/duplicate-diag', [
              "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
              "confirmDuplicate" => "OK",
        ],[],[
            'Hx-Request' => true
        ]);
           $diagsForCommnune = $this->diagRepository->findAll(10);
           reset($diagsForCommnune);
           $latestDiagUuid = current($diagsForCommnune)->duplicatedFrom;
        $this->assertResponseRedirects('/commune-epci/diagnostics');
        $this->assertEquals($this->diagUuid, $latestDiagUuid);
    }

}
