<?php

namespace App\Tests\Controller;

use App\Entity\DiagnosticCycloDiag;
use App\Entity\InviteConsultantToken;
use App\Entity\User;
use App\Entity\UserBeneficiaireRole;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\UserRepository;
use App\Repository\InviteTokenRepository;
use Symfony\Bundle\FrameworkBundle\KernelBrowser;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class CommuneEPCIInviteConsultantControllerTest extends WebTestCase
{

    private KernelBrowser $client;
    private DiagnosticCycloDiagRepository $DiagRepository;
    private UserRepository $userRepository;

    protected function setUp(): void
    {
        $this->client = static::createClient();
        $this->userRepository = static::getContainer()->get(UserRepository::class);

        $this->DiagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);

    }
    public function testThatExistingEmailWorks(): void
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->DiagRepository->save($diag);

        // retrieve the test user
        $testUser = $this->userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $this->client->loginUser($testUser);

        $crawler = $this->client->request('POST', '/commune-epci/make-invite', [
              "consultantNameEmail" => "Martin Dupont <miserable@victor.hugo>",
              "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
              "questionInputName" => "contexte-i-population",
        ]);
//        dd($client->getResponse());
        $this->assertResponseIsSuccessful();
        $this->assertSelectorExists('dialog');
    }
    public function testThatNormal(): void
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->DiagRepository->save($diag);

        // retrieve the test user
        $testUser = $this->userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $this->client->loginUser($testUser);

        $crawler = $this->client->request('POST', '/commune-epci/make-invite', [
              "consultantNameEmail" => "Martin Dupont <martin.dupont@ville-nantes.fr>",
              "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
              "questionInputName" => "contexte-i-population",
        ]);
//        dd($client->getResponse());
        $this->assertResponseIsSuccessful();
        $this->assertSelectorExists('dialog');
    }

    public function testThatOldTokenAreRemoved()
    {
        $inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);

        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->DiagRepository->save($diag);

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109, // martin dupont
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);


        $testUser = $this->userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $this->client->loginUser($testUser);

        $crawler = $this->client->request('POST', '/commune-epci/make-invite', [
              "consultantNameEmail" => "Martin Dupont <martin.dupont@ville-nantes.fr>",
              "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
              "questionInputName" => "diagnostic-reglementaire-circulation",
        ]);
        $newInviteToken = InviteConsultantToken::fromDB($inviteTokenRepository->getAll()[0]);

        $this->assertNotEquals('16bee687', $newInviteToken->selector);
    }
}
