<?php

namespace App\Tests\Controller;

use App\Entity\DiagnosticCycloDiag;
use App\Entity\InviteConsultantToken;
use App\Entity\User;
use App\Entity\UserBeneficiaireRole;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\InviteTokenRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class CommuneEPCIQuestionnaireControllerTest extends WebTestCase
{
    public function testThatConsultantRespondToTwoQuestions():void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $DiagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $DiagRepository->save($diag);

        // test user 109

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "7c958685",
          'userId' => 109,
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "19e58da48770ef236dede5f51acce74d62006cb8e213469648c213932e824c3d"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "a83028da",
          'userId' => 109,
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-foncier-espace_lgtq",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "9cbce367b49ec7bf7c2583d97b5b5e6e35e8c81febc9c8d31858198a5e83515e"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);
        //dd($inviteTokenRepository->getAll());

        $client->request('GET', '/consultant-response/a83028da193315cd8871081e6418114d');
        $this->assertResponseRedirects('/commune-epci/questionnaire/DIAGNOSTIC/6648a5fa-eb0f-4629-8283-6e5b6c4611ea#diagnostic-foncier-espace_lgtq');
        $client->followRedirect();
        $this->assertSelectorExists('form.response-waiting');
        $this->assertSelectorCount(2, 'form.response-waiting');
//        dd($client->getResponse()->getStatusCode());
    }

    public function testThatConsultantResponding():void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $DiagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $DiagRepository->save($diag);

        // test user 109
        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109,
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);

        // -verifier: "5998c036d1188f88127c8742"
        $crawler = $client->request('GET', '/consultant-response/16bee6875998c036d1188f88127c8742');
        $this->assertResponseRedirects('/commune-epci/questionnaire/DIAGNOSTIC/6648a5fa-eb0f-4629-8283-6e5b6c4611ea#diagnostic-reglementaire-circulation');
        $client->followRedirect();
        $this->assertSelectorExists('form.response-waiting');
        $this->assertSelectorCount(1, 'form.response-waiting');
//        dd($client->getResponse()->getStatusCode());
    }

    public function testThatLoggedInUserCanAccesDiag(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $DiagRepository = static::getContainer()->get('App\Repository\DiagnosticCycloDiagRepository');
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $DiagRepository->save($diag);

        // retrieve the test user
        $testUser = $userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $client->loginUser($testUser);

        $crawler = $client->request('GET', 'http://127.0.0.1:32880/commune-epci/questionnaire/CONTEXTE/6648a5fa-eb0f-4629-8283-6e5b6c4611ea');
        $this->assertResponseIsSuccessful();
//        dd($client->getResponse());
//        $this->assertSelectorTextContains('h1', 'Hello World');
    }
}
