<?php

namespace App\Tests\Controller;

use App\Entity\DiagnosticCycloDiag;
use App\Entity\InviteConsultantToken;
use App\Entity\User;
use App\Entity\UserBeneficiaireRole;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\InviteTokenRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class ConsultantConnectForResponseControllerTest extends WebTestCase
{
    public function testInvalidInviteTokenRedirectsToHome(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $DiagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $DiagRepository->save($diag);

        // retrieve the test user
        $user = new User();
        $user->setCommuneEPCIid(10);
        $user->setRoles([UserBeneficiaireRole::ROLE_BENEFICIAIRE->value]);
        $user->setFullname('Martin Dupont');
        $user->setEmail('martin.dupont@ville-nantes.fr');
        $userRepository->save($user, true);

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => $user->getId(),
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);
        $crawler = $client->request('GET', '/consultant-response/16bee6875998c036d1188f8xyuhbhuxx');
//        dd($client->getResponse());

        $this->assertResponseRedirects('/');
    }
    public function testValidInviteTokenRedirectsToQuestionnaire(): void
    {
        $client = static::createClient();
        $userRepository = static::getContainer()->get(UserRepository::class);
        $DiagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $DiagRepository->save($diag);

        // retrieve the test user
        $user = new User();
        $user->setCommuneEPCIid(10);
        $user->setRoles([UserBeneficiaireRole::ROLE_BENEFICIAIRE->value]);
        $user->setFullname('Martin Dupont');
        $user->setEmail('martin.dupont@ville-nantes.fr');
        $user->setPassword(bin2hex(random_bytes(8)));
        $userRepository->save($user, true);

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => $user->getId(),
          'diagUuid' => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $inviteTokenRepository->save($inviteConsultantToken);

        // -verifier: "5998c036d1188f88127c8742"
        $crawler = $client->request('GET', '/consultant-response/16bee6875998c036d1188f88127c8742');
//        dd($client->getResponse());
        $cookie = $client->getCookieJar()->get('MOCKSESSID');
        $this->assertInstanceOf('Symfony\Component\BrowserKit\Cookie', $cookie);
        // $this->assertResponseHasCookie(); not working

        $this->assertResponseRedirects('/commune-epci/questionnaire/DIAGNOSTIC/6648a5fa-eb0f-4629-8283-6e5b6c4611ea#diagnostic-reglementaire-circulation');
    }

}
