<?php

namespace App\Tests\Repository\Controller;

use App\Entity\BeneficiaireAdminReminderDTO;
use App\Entity\DiagnosticCycloDiag;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\ReminderLogRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class QuestionnaireQuestionControllerTest extends WebTestCase
{
    public function testThatReminderLogIsRemovedWhenQuestionIsAnswered(): void
    {
        $client = static::createClient();
        $diagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $reminderLogRepo = static::getContainer()->get(ReminderLogRepository::class);
        $userRepository = static::getContainer()->get(UserRepository::class);

        $diag = DiagnosticCycloDiag::create([
            'uuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $diagRepository->save($diag);

        $beneficaireLog = BeneficiaireAdminReminderDTO::fromDatabaseRecord([
            'userId'=> 23,
            'fullName'=> 'Jean Valjean',
            'email'=> 'miserable@victor.hugo',
            'diagUuid'=> '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'lastResponse'=> '2024-08-01 15:00',
            'responseCount'=> 10,
            'sent' => null,
        ]);
        $reminderLogRepo->save($beneficaireLog);


        $testUser = $userRepository->findOneByEmail('miserable@victor.hugo');

        // simulate $testUser being logged in
        $client->loginUser($testUser);

        $crawler = $client->request('POST', '/commune-epci/questionnaire-question/contexte-i-population', [
            'question-4' => [
                "contexte-i-population" => "15222"
            ],
          "questionInputName" => "contexte-i-population",
            "diagUuid" => "6648a5fa-eb0f-4629-8283-6e5b6c4611ea",
          'stepName' => 'contexte',
        ]);

        $this->assertEmpty($reminderLogRepo->getAll());

        $this->assertResponseRedirects('/commune-epci/questionnaire/CONTEXTE/6648a5fa-eb0f-4629-8283-6e5b6c4611ea');
    }
}
