<?php

namespace App\Tests;

use App\Entity\IndiceOperateur;
use Assert\LazyAssertionException;
use Symfony\Bundle\FrameworkBundle\Test\KernelTestCase;
use Symfony\Component\HttpFoundation\Request;

class IndiceOperateurTest extends KernelTestCase
{
    private $payload = [];
    protected function setUp(): void
    {
        $this->payload = [
                'collectivite' => 'Toulouse',
                'entreprise' => 'coursier toulouse',
                'reglementation_rank' => '5',
                'reglementation_commentaire' => 'Il sort par la pluie, il marche dans l’eau, il voyage en hiver. Il n’a pas peur de la nuit, des routes suspectes ni des rencontres',
                'foncier_rank' => '3',
                'foncier_commentaire' => 'Voilà comme il faut être avec un homme qui a du grand dans l’esprit.',
                'ammenagement_securite_rank' => '4',
                'ammenagement_lieux_rank' => '3',
                'ammenagement_stationnement_rank' => '5',
                'ammenagement_commentaire' => 'Il y avait près de Digne, dans la campagne, un homme qui vivait solitaire',
                'politique_rank' => '3',
                'politique_commentaire' => 'Cet homme, disons tout de suite le gros mot, était un ancien conventionnel. Il se nommait G.',
                'emploi_rank' => '2',
                'emploi_commentaire' => 'Était-ce du reste un vautour que G.? Oui, si l’on en jugeait par ce qu’il y avait de farouche dans sa solitude',
                'investissement_rank' => '3',
                'investissement_commentaire' => 'L’évêque prit son bâton, mit son pardessus à cause de sa soutane un peu trop usée',
                'communication_rank' => '5',
                'communication_commentaire' => 'C’était une cabane toute basse, indigente, petite et propre, avec une treille clouée à la façade.',
                'priorite_levier' => [
                    0 => 'Réglementation',
                    1 => 'Foncier',
                    2 => 'Aménagement',
                    3 => 'Emploi',
                    4 => 'Investissement',
                    5 => 'Communication'],
        ];
    }
    public function testThatOutOfRangeRankThrows(): void
    {
        $kernel = self::bootKernel();

        $this->assertSame('test', $kernel->getEnvironment());
        // $routerService = static::getContainer()->get('router');
        // $myCustomService = static::getContainer()->get(CustomService::class);

        $this->expectException('Assert\LazyAssertionException');
        $badPayload = $this->payload;
        $badPayload['reglementation_rank'] = 10;

        try {
        $indiceOperateur = IndiceOperateur::fromRequest(Request::create('/indice-operateur', 'POST', $badPayload));
        } catch (Assert\LazyAssertionException $e){
//            dump($e);
            $error = $e->getErrorExceptions()[0];
//            dump($error->getPropertyPath());
//            dump($error->getConstraints());
//            dd($error->getMessage());
        $this->assertEquals('Le champ "reglementation" doit comporter entre entre 1 et 5 étoiles', $error->getMessage());
        }

    }

    public function testThatOutOfValuesThrows(): void
    {
        $kernel = self::bootKernel();

        $this->assertSame('test', $kernel->getEnvironment());
        // $routerService = static::getContainer()->get('router');
        // $myCustomService = static::getContainer()->get(CustomService::class);

        $this->expectException('Assert\LazyAssertionException');
        $badPayload = $this->payload;
        $badPayload['priorite_levier'][0] = 'Bad value';
        try {

        $indiceOperateur = IndiceOperateur::fromRequest(Request::create('/indice-operateur', 'POST', $badPayload));
        } catch (Assert\LazyAssertionException $e){
//            dump($e);
            $error = $e->getErrorExceptions()[0];
//            dump($error->getPropertyPath());
//            dump($error->getConstraints());
//            dd($error->getMessage());
            $this->assertEquals('Une des valeurs de levier d’action ne correspond pas à la liste', $e->getMessage());
        }

    }
}
