<?php

namespace App\Tests;

use App\Questionnaire\PublicPageBuilder;
use PHPUnit\Framework\TestCase;

class PublicPageBuilderTest extends TestCase
{
    public function testIdentiteTerritoire(): void
    {
        $indexedResponses = [
            'contexte-i-echelon' => [
                'value' => 'Commune'],
            'contexte-i-nom_commune' => [
                'value' => 'Nantes'],
            'contexte-i-population' => [
                'value' => '112233'],
            'contexte-i-superficie' => [
                'value' => '445566'],
            'contexte-i-densite' => [
                'value' => '11'],
        ];
        $page = PublicPageBuilder::page($indexedResponses);
//        dd($page);
        $this->assertEquals
        ("<h3>Fiche d’identité cyclologistique du territoire</h3>
<p>La Commune de Nantes compte 112233 habitants sur une superficie de 445566 km² soit une densité de population de 11.</p>", $page);
    }

    public function testRestrictionCirculation(): void
    {
        $indexedResponses = [
            'contexte-i-echelon' => [
                'value' => 'Commune'],
            'contexte-i-nom_commune' => [
                'value' => 'Nantes'],
            'contexte-i-population' => [
                'value' => '112233'],
            'contexte-i-superficie' => [
                'value' => '445566'],
            'contexte-i-densite' => [
                'value' => '11'],
            'diagnostic-reglementaire-circulation' => [
                'value' => 'oui',
                'other' => 'ZFE patapata'],
            'diagnostic-reglementaire-circulation-motorisation' => [
                'value' => '5'],
        ];
        $page = PublicPageBuilder::page($indexedResponses);
//        dd($page);
        $this->assertEquals('<h3>Fiche d’identité cyclologistique du territoire</h3>
<p>La Commune de Nantes compte 112233 habitants sur une superficie de 445566 km² soit une densité de population de 11.</p><p>Il existe sur notre territoire des restrictions à la circulation des véhicules professionnels motorisés identifiées par <span class="to-review">ZFE patapata</span>, qui interdisent aux vignettes Crit’Air <span class="to-review">5</span> de circuler.</p>', $page);
    }

    public function testPolLog(): void
    {
        $indexedResponses = [
            'contexte-i-echelon' => [
                'value' => 'Commune'],
            'contexte-i-nom_commune' => [
                'value' => 'Nantes'],
            'contexte-i-population' => [
                'value' => '112233'],
            'contexte-i-superficie' => [
                'value' => '445566'],
            'contexte-i-densite' => [
                'value' => '11'],
            'diagnostic-reglementaire-circulation' => [
                'value' => 'oui',
                'other' => 'ZFE patapata'],
            'diagnostic-reglementaire-circulation-motorisation' => [
                'value' => '5'],
            'gouvernance-portage-politique_cyclo' => [
                'value' => 'oui',
                'other' => 'qsfdksmfkdmfkdfkl'
            ],
            'gouvernance-autre-etude_cyclo' => [
                'value' => 'oui'
            ]
        ];
        $page = PublicPageBuilder::page($indexedResponses);
//        dd($page);
        $this->assertEquals('<h3>Fiche d’identité cyclologistique du territoire</h3>
<p>La Commune de Nantes compte 112233 habitants sur une superficie de 445566 km² soit une densité de population de 11.</p><p>Il existe sur notre territoire des restrictions à la circulation des véhicules professionnels motorisés identifiées par <span class="to-review">ZFE patapata</span>, qui interdisent aux vignettes Crit’Air <span class="to-review">5</span> de circuler.</p><p>Notre politique de logistique urbaine inclut la cyclologistique et prévoit <span class="to-review">qsfdksmfkdmfkdfkl</span>. Une étude spécifique avait été menée sur ce sujet en <span class="to-review">Date à renseigner</span> </p>', $page);
    }
}
