<?php

namespace App\Tests;

use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

class RegisterUserTest extends WebTestCase
{
    public function testThatHoneypotFilledDoesNotCreateUser(): void
    {
        $client = static::createClient();
        $crawler = $client->request('GET', '/creer-compte');
        $buttonCrawlerNode = $crawler->selectButton('submit');

// retrieve the Form object for the form belonging to this button
        $form = $buttonCrawlerNode->form();
        $client->submit($form, [
            'registration_form[nomCollectivite]' => 'Toulouse',
            'registration_form[region]' => 'Nouvelle-Aquitaine',
            'registration_form[fullname]' => 'Jean Valjean',
            'registration_form[email]' => 'miserable@victor.hugo',
            'registration_form[plainPassword]' => 'jejejejejejejejej',
            'registration_form[bestTimeContact]' => '1',
        ]);

//        dd($client->getResponse());
        $this->assertResponseRedirects('/');
    }
    public function testThatValidValuesCreateUser(): void
    {
        $client = static::createClient();
        $crawler = $client->request('GET', '/creer-compte');
        $buttonCrawlerNode = $crawler->selectButton('submit');

// retrieve the Form object for the form belonging to this button
        $form = $buttonCrawlerNode->form();
        $client->submit($form, [
            'registration_form[nomCollectivite]' => 'Toulouse',
            'registration_form[region]' => 'Nouvelle-Aquitaine',
            'registration_form[fullname]' => 'Jean Valjean',
            'registration_form[email]' => 'miserable@victor.hugo',
            'registration_form[plainPassword]' => 'jejejejejejejejej',
        ]);

        $userRepository = static::getContainer()->get(UserRepository::class);
        $testUser = $userRepository->findOneByEmail('miserable@victor.hugo');
//        dd($client->getResponse());

        $this->assertInstanceOf('App\Entity\User' , $testUser);
    }

    public function testThatNotProEmailReturnErrorMessage(): void
    {
        $client = static::createClient();
        $crawler = $client->request('GET', '/creer-compte');
        $buttonCrawlerNode = $crawler->selectButton('submit');

// retrieve the Form object for the form belonging to this button
        $form = $buttonCrawlerNode->form();
        $client->submit($form, [
            'registration_form[nomCollectivite]' => 'Annecy',
            'registration_form[region]' => 'Auvergne-Rhône-Alpes',
            'registration_form[fullname]' => 'test email not pro',
            'registration_form[email]' => 'test@gmail.com',
            'registration_form[plainPassword]' => 'fgfgfgfgfgfgfgfgfgkkkkkkk',

        ]);
//        dd($client->getResponse());

        $this->assertResponseStatusCodeSame(422);
        $this->assertSelectorExists('label[for=registration_form_email] + ul');
    }

    public function testThatEmptyValuesReturnErrorMessage(): void
    {
        $client = static::createClient();
        $crawler = $client->request('GET', '/creer-compte');
        $buttonCrawlerNode = $crawler->selectButton('submit');

// retrieve the Form object for the form belonging to this button
        $form = $buttonCrawlerNode->form();
        $client->submit($form, [
            'registration_form[nomCollectivite]' => '',
            'registration_form[region]' => '',
            'registration_form[fullname]' => '',
            'registration_form[email]' => '',
            'registration_form[plainPassword]' => '',

        ]);
//        dd($client->getResponse());

        $this->assertResponseStatusCodeSame(422);
        $this->assertSelectorExists('label + ul');
        $this->assertSelectorCount(5, 'label + ul');
    }
}
