<?php

namespace App\Tests\Repository;

use App\Config\ReminderInterval;
use App\Entity\BeneficiaireAdminReminderDTO;
use App\Entity\CollegueReminderDTO;
use App\Entity\DiagnosticCycloDiag;
use App\Entity\InviteConsultantToken;
use App\Entity\ResponseCycloDiag_DTO;
use App\Repository\DiagnosticCycloDiagRepository;
use App\Repository\InviteTokenRepository;
use App\Repository\ReminderLogRepository;
use App\Repository\ResponseCycloDiagRepository;
use App\Repository\UserReminderRepository;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Test\KernelTestCase;

class UserReminderRepositoryTest extends KernelTestCase
{
    private InviteTokenRepository $inviteTokenRepository;
    private DiagnosticCycloDiagRepository $diagRepository;
    private ResponseCycloDiagRepository $responseRepo;
    private ReminderLogRepository $reminderLogRepo;
    private UserReminderRepository $userReminderRepo;
    private $diagUuid = '6648a5fa-eb0f-4629-8283-6e5b6c4611ea';

    protected function setup(): void
    {

        $this->diagRepository = static::getContainer()->get(DiagnosticCycloDiagRepository::class);
        $this->responseRepo = static::getContainer()->get(ResponseCycloDiagRepository::class);
        $this->reminderLogRepo = static::getContainer()->get(ReminderLogRepository::class);
        $this->userReminderRepo = static::getContainer()->get(UserReminderRepository::class);
        $this->inviteTokenRepository = static::getContainer()->get(InviteTokenRepository::class);
    }

    public function testThatLastResponseOlderThan10DaysReturnOneReminder(): void
    {
        $kernel = self::bootKernel();
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-10 day'));
        $responseToTest = ResponseCycloDiag_DTO::fromDBRecord([
            'diagUuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'inputName' => 'diagnostic-reglementaire-circulation-perimetre',
            'step' => 'DIAGNOSTIC',
            'value' => 789456123000,
            'other' => null,
            'version' => 0
        ]);
        $this->responseRepo->save($responseToTest);

        $oneReminder = $this->userReminderRepo->findBeneficiaireAdminToSendReminder()[0];
        $this->assertInstanceOf('App\Entity\BeneficiaireAdminReminderDTO', $oneReminder);

    }
    public function testThatLastResponseOlderThan30DaysAndJ10ReminderSentReturnOneReminder(): void
    {
        $kernel = self::bootKernel();
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-31 day'));
        $responseToTest = ResponseCycloDiag_DTO::fromDBRecord([
            'diagUuid' => '6648a5fa-eb0f-4629-8283-6e5b6c4611ea',
            'inputName' => 'diagnostic-reglementaire-circulation-perimetre',
            'step' => 'DIAGNOSTIC',
            'value' => 789456123000,
            'other' => null,
            'version' => 0
        ]);
        $this->responseRepo->save($responseToTest);

        $beneficaireLog = BeneficiaireAdminReminderDTO::fromDatabaseRecord([
            'userId'=> 23,
            'fullName'=> 'Jean Valjean',
            'email'=> 'miserable@victor.hugo',
            'diagUuid'=> $this->diagUuid,
            'lastResponse'=> (new \DateTimeImmutable('-30 day'))->format('Y-m-d H:i:s'),
            'responseCount'=> 10,
            'sent' => null,
        ]);
        $beneficaireLog->setSent();
        $this->reminderLogRepo->save($beneficaireLog);
//        dd($this->reminderLogRepo->getAll());
        $this->assertEquals('J+10', $this->reminderLogRepo->getAll()[0]['sent']);

        $oneReminder = $this->userReminderRepo->findBeneficiaireAdminToSendReminder()[0];
        $this->assertInstanceOf('App\Entity\BeneficiaireAdminReminderDTO', $oneReminder);
    }

    public function testThatLastResponseFromCollegueOlderThan7DaysReturnOneReminder()
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-7 day'));

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109, // martin dupont
          'diagUuid' => $this->diagUuid,
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $this->inviteTokenRepository->save($inviteConsultantToken);

//        dd($this->userReminderRepo->findCollegueToSendReminder());
        $oneReminder = $this->userReminderRepo->findCollegueToSendReminder()[0];
        $this->assertInstanceOf('App\Entity\CollegueReminderDTO', $oneReminder);
    }

    public function testThatLastResponseOfManyFromCollegueOlderThan7DaysReturnOneReminder()
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-7 day'));

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109, // martin dupont
          'diagUuid' => $this->diagUuid,
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $this->inviteTokenRepository->save($inviteConsultantToken);
        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee123",
          'userId' => 109, // martin dupont
          'diagUuid' => $this->diagUuid,
          'questionInputName' => "diagnostic-amenagement-indice_cycla-bidirec",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $this->inviteTokenRepository->save($inviteConsultantToken);

        $responseToTest = ResponseCycloDiag_DTO::fromDBRecord([
            'diagUuid' => $this->diagUuid,
            'inputName' => 'diagnostic-reglementaire-circulation',
            'step' => 'DIAGNOSTIC',
            'value' => 'loren ipsum',
            'other' => null,
            'version' => 0
        ]);
        $this->responseRepo->save($responseToTest);

//        dd($this->userReminderRepo->findCollegueToSendReminder());
        $oneReminder = $this->userReminderRepo->findCollegueToSendReminder()[0];
        $this->assertInstanceOf('App\Entity\CollegueReminderDTO', $oneReminder);
        $this->assertEquals(2, $oneReminder->qsToRespondCount);
        $this->assertEquals(1, $oneReminder->qsRespondedCount);
    }

    public function testThatLastResponseFromCollegueOlderThan14DaysAndJ7ReminderSentReturnOneReminder()
    {
        $diag = DiagnosticCycloDiag::create([
            'uuid' => $this->diagUuid,
            'communeEPCI_id' => 10,
            'ownerId' => 23,
            'name' => 'test diag',
        ]);
        $this->diagRepository->save($diag);
        $this->diagRepository->setUpdated($diag, new \DateTimeImmutable('-10 day'));

        $inviteConsultantToken = InviteConsultantToken::fromDB([
          'selector' => "16bee687",
          'userId' => 109, // martin dupont
          'diagUuid' => $this->diagUuid,
          'questionInputName' => "diagnostic-reglementaire-circulation",
          'expiresAt' => (new \DateTimeImmutable('+1 month'))->format('Y-m-d H:i:s'),
          'hashedVerifier' => "21a26b66265fa366fda4ca676a719712b2304eb727c1ec568c6a3edd11f61b96"
        ]);
        $this->inviteTokenRepository->save($inviteConsultantToken);

        $collegueLog = CollegueReminderDTO::fromDatabaseRecord([
            'userId'=> 23,
            'fullName'=> 'Jean Valjean',
            'email'=> 'miserable@victor.hugo',
            'diagUuid'=> $this->diagUuid,
            'lastResponse'=> (new \DateTimeImmutable('-14 day'))->format('Y-m-d H:i:s'),
            'qsToRespond' => '["diagnostic-reglementaire-circulation-perimetre"]',
            'qsToRespondCount'=> 1,
            'qsRespondedCount'=> 0,
            'sent' => null,
        ]);
        $collegueLog->setSent();
        $this->reminderLogRepo->save($collegueLog);
//        dd($this->reminderLogRepo->getAll());
        $this->assertEquals('J+7', $this->reminderLogRepo->getAll()[0]['sent']);

//        dd($this->userReminderRepo->findCollegueToSendReminder());
        $oneReminder = $this->userReminderRepo->findCollegueToSendReminder()[0];
        $this->assertInstanceOf('App\Entity\CollegueReminderDTO', $oneReminder);
    }
}
